@@ -57,7 +57,7 @@ def args(*params) -> Dict[int, Any]:
 class _CborDataObject(_DataClassMapping[int]):
     @classmethod
     def _get_field_key(cls, field: Field) -> int:
-        return fields(cls).index(field) + 1
+        return fields(cls).index(field) + 1  # type: ignore
 
 
 @dataclass(eq=False, frozen=True)
@@ -168,7 +168,7 @@ class AssertionResponse(_CborDataObject):
             credential=credential,
             auth_data=AuthenticatorData.create(
                 app_param,
-                authentication.user_presence & AuthenticatorData.FLAG.USER_PRESENT,
+                authentication.user_presence & AuthenticatorData.FLAG.UP,
                 authentication.counter,
             ),
             signature=authentication.signature,
@@ -353,6 +353,7 @@ class Ctap2:
         :param options: Optional dict of options.
         :param pin_uv_param: Optional PIN/UV auth parameter.
         :param pin_uv_protocol: The version of PIN/UV protocol used, if any.
+        :param enterprise_attestation: Whether or not to request Enterprise Attestation.
         :param event: Optional threading.Event used to cancel the request.
         :param on_keepalive: Optional callback function to handle keep-alive
             messages from the authenticator.
